| Title: | Chen datasets for the ggseg-plotting tool |
|---|---|
| Description: | This is a support package for the ggseg, and ggseg3d packages. It contains the Chen atlases to plot using functions from those two packages. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>), Didac Vidal-PiƱeiro [aut] (ORCID: <https://orcid.org/0000-0001-9997-9156>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.01 |
| Built: | 2026-05-24 07:04:08 UTC |
| Source: | https://github.com/ggsegverse/ggsegChen |
Genetic topography of brain area morphology with 12 cortical regions per hemisphere based on Chen et al. (2013).
chenAr()chenAr()
A [ggseg.formats::ggseg_atlas] object (cortical).
Chen C-H, et al. (2013). Genetic topography of brain morphology. *PNAS*, 110(42), 17089-17094. doi:10.1073/pnas.1308091110
Other ggseg_atlases:
chenTh()
Other cortical_atlases:
chenTh()
chenAr()chenAr()
Genetic topography of brain thickness morphology with 12 cortical regions per hemisphere based on Chen et al. (2013).
chenTh()chenTh()
A [ggseg.formats::ggseg_atlas] object (cortical).
Chen C-H, et al. (2013). Genetic topography of brain morphology. *PNAS*, 110(42), 17089-17094. doi:10.1073/pnas.1308091110
Other ggseg_atlases:
chenAr()
Other cortical_atlases:
chenAr()
chenTh()chenTh()